@@ -8,12 +8,12 @@
 #include "kprocessrunner_p.h"
 
 #if defined(Q_OS_LINUX) && !defined(Q_OS_ANDROID)
-#include "systemd/systemdprocessrunner_p.h"
 #include "systemd/scopedprocessrunner_p.h"
+#include "systemd/systemdprocessrunner_p.h"
 #endif
 
-#include "kiogui_debug.h"
 #include "config-kiogui.h"
+#include "kiogui_debug.h"
 
 #include "desktopexecparser.h"
 #include "krecentdocument.h"
@@ -27,14 +27,21 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QGuiApplication>
+#include <QProcess>
 #include <QStandardPaths>
 #include <QString>
 #include <QUuid>
 
+#ifdef Q_OS_WIN
+#include "windows.h"
+
+#include "shellapi.h" // Must be included after "windows.h"
+#endif
+
 static int s_instanceCount = 0; // for the unittest
 
 KProcessRunner::KProcessRunner()
-    : m_process {new KProcess}
+    : m_process{new KProcess}
 {
     ++s_instanceCount;
 }
@@ -55,6 +62,7 @@ static KProcessRunner *makeInstance()
 }
 
 KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
+                                                const QString &serviceEntryPath,
                                                 const QList<QUrl> &urls,
                                                 KIO::ApplicationLauncherJob::RunFlags flags,
                                                 const QString &suggestedFileName,
@@ -63,7 +71,7 @@ KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
     auto instance = makeInstance();
 
     if (!service->isValid()) {
-        instance->emitDelayedError(i18n("The desktop entry file\n%1\nis not valid.", service->entryPath()));
+        instance->emitDelayedError(i18n("The desktop entry file\n%1\nis not valid.", serviceEntryPath));
         return instance;
     }
 
@@ -118,7 +126,7 @@ KProcessRunner *KProcessRunner::fromApplication(const KService::Ptr &service,
         }
     }
 
-    instance->init(service, service->name(), service->icon(), asn);
+    instance->init(service, serviceEntryPath, service->name(), service->icon(), asn);
     return instance;
 }
 
@@ -127,35 +135,51 @@ KProcessRunner *KProcessRunner::fromCommand(const QString &cmd,
                                             const QString &execName,
                                             const QString &iconName,
                                             const QByteArray &asn,
-                                            const QString &workingDirectory)
+                                            const QString &workingDirectory,
+                                            const QProcessEnvironment &environment)
 {
     auto instance = makeInstance();
 
     instance->m_executable = KIO::DesktopExecParser::executablePath(execName);
-    instance->m_process->setShellCommand(cmd);
+#ifdef Q_OS_WIN
+    if (cmd.startsWith(QLatin1String("wt.exe")) || cmd.startsWith(QLatin1String("pwsh.exe")) || cmd.startsWith(QLatin1String("powershell.exe"))) {
+        instance->m_process->setCreateProcessArgumentsModifier([](QProcess::CreateProcessArguments *args) {
+            args->flags |= CREATE_NEW_CONSOLE;
+            args->startupInfo->dwFlags &= ~STARTF_USESTDHANDLES;
+        });
+        const int firstSpace = cmd.indexOf(QLatin1Char(' '));
+        instance->m_process->setProgram(cmd.left(firstSpace));
+        instance->m_process->setNativeArguments(cmd.mid(firstSpace + 1));
+    } else
+#endif
+        instance->m_process->setShellCommand(cmd);
     if (!workingDirectory.isEmpty()) {
         instance->m_process->setWorkingDirectory(workingDirectory);
     }
+    instance->m_process->setProcessEnvironment(environment);
     if (!desktopName.isEmpty()) {
         KService::Ptr service = KService::serviceByDesktopName(desktopName);
         if (service) {
             if (instance->m_executable.isEmpty()) {
                 instance->m_executable = KIO::DesktopExecParser::executablePath(service->exec());
             }
-            instance->init(service, service->name(), service->icon(), asn);
+            instance->init(service, service->entryPath(), service->name(), service->icon(), asn);
             return instance;
         }
     }
-    instance->init(KService::Ptr(), execName /*user-visible name*/, iconName, asn);
+    instance->init(KService::Ptr(), QString{}, execName /*user-visible name*/, iconName, asn);
     return instance;
 }
 
-
-void KProcessRunner::init(const KService::Ptr &service, const QString &userVisibleName, const QString &iconName, const QByteArray &asn)
+void KProcessRunner::init(const KService::Ptr &service,
+                          const QString &serviceEntryPath,
+                          const QString &userVisibleName,
+                          const QString &iconName,
+                          const QByteArray &asn)
 {
-    if (service && !service->entryPath().isEmpty()
-            && !KDesktopFile::isAuthorizedDesktopFile(service->entryPath())) {
-        qCWarning(KIO_GUI) << "No authorization to execute" << service->entryPath();
+    m_serviceEntryPath = serviceEntryPath;
+    if (service && !serviceEntryPath.isEmpty() && !KDesktopFile::isAuthorizedDesktopFile(serviceEntryPath)) {
+        qCWarning(KIO_GUI) << "No authorization to execute" << serviceEntryPath;
         emitDelayedError(i18n("You are not authorized to execute this file."));
         return;
     }
@@ -193,18 +217,19 @@ void KProcessRunner::init(const KService::Ptr &service, const QString &userVisib
                 data.setSilent(KStartupInfoData::Yes);
             }
             data.setDesktop(KWindowSystem::currentDesktop());
-            if (service && !service->entryPath().isEmpty()) {
-                data.setApplicationId(service->entryPath());
+            if (service && !serviceEntryPath.isEmpty()) {
+                data.setApplicationId(serviceEntryPath);
             }
             KStartupInfo::sendStartup(m_startupId, data);
         }
     }
 #else
-    Q_UNUSED(bin);
     Q_UNUSED(userVisibleName);
     Q_UNUSED(iconName);
 #endif
+
     if (service) {
+        m_service = service;
         // Store the desktop name, used by debug output and for the systemd unit name
         m_desktopName = service->menuId();
         if (m_desktopName.endsWith(QLatin1String(".desktop"))) { // always true, in theory
@@ -214,7 +239,7 @@ void KProcessRunner::init(const KService::Ptr &service, const QString &userVisib
             // desktopEntryName is lowercase so this is only a fallback
             m_desktopName = service->desktopEntryName();
         }
-        m_desktopFilePath = QFileInfo(service->entryPath()).absoluteFilePath();
+        m_desktopFilePath = QFileInfo(serviceEntryPath).absoluteFilePath();
         m_description = service->name();
         if (!service->genericName().isEmpty()) {
             m_description.append(QStringLiteral(" - %1").arg(service->genericName()));
@@ -227,14 +252,44 @@ void KProcessRunner::init(const KService::Ptr &service, const QString &userVisib
 
 void ForkingProcessRunner::startProcess()
 {
-    connect(m_process.get(), QOverload<int,QProcess::ExitStatus>::of(&QProcess::finished),
-            this, &ForkingProcessRunner::slotProcessExited);
-    connect(m_process.get(), &QProcess::started,
-            this, &ForkingProcessRunner::slotProcessStarted, Qt::QueuedConnection);
-    connect(m_process.get(), &QProcess::errorOccurred,
-            this, &ForkingProcessRunner::slotProcessError);
+    connect(m_process.get(), QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &ForkingProcessRunner::slotProcessExited);
+    connect(m_process.get(), &QProcess::started, this, &ForkingProcessRunner::slotProcessStarted, Qt::QueuedConnection);
+    connect(m_process.get(), &QProcess::errorOccurred, this, &ForkingProcessRunner::slotProcessError);
 
-    m_process->start();
+    bool waitingForXdgToken = false;
+    if (KWindowSystem::isPlatformWayland() && m_service) {
+        bool silent;
+        QByteArray wmclass;
+        const bool startup_notify = KIOGuiPrivate::checkStartupNotify(m_service.data(), &silent, &wmclass);
+        if (startup_notify && !silent) {
+            auto window = qGuiApp->focusWindow();
+            if (!window && !qGuiApp->allWindows().isEmpty()) {
+                window = qGuiApp->allWindows().constFirst();
+            }
+
+            if (window) {
+                const int launchedSerial = KWindowSystem::lastInputSerial(window);
+                waitingForXdgToken = true;
+                connect(this, &ForkingProcessRunner::xdgActivationTokenArrived, m_process.get(), [this] {
+                    m_process->start();
+                });
+                connect(KWindowSystem::self(),
+                        &KWindowSystem::xdgActivationTokenArrived,
+                        m_process.get(),
+                        [this, launchedSerial](int tokenSerial, const QString &token) {
+                            if (tokenSerial == launchedSerial) {
+                                m_process->setEnv(QStringLiteral("XDG_ACTIVATION_TOKEN"), token);
+                                Q_EMIT xdgActivationTokenArrived();
+                            }
+                        });
+                KWindowSystem::requestXdgActivationToken(window, launchedSerial, QFileInfo(m_serviceEntryPath).completeBaseName());
+            }
+        }
+    }
+
+    if (!waitingForXdgToken) {
+        m_process->start();
+    }
 }
 
 bool ForkingProcessRunner::waitForStarted(int timeout)
@@ -269,8 +324,8 @@ void KProcessRunner::setPid(qint64 pid)
             KStartupInfo::resetStartupEnv();
         }
 #endif
+        Q_EMIT processStarted(pid);
     }
-    Q_EMIT processStarted(pid);
 }
 
 KProcessRunner::~KProcessRunner()
@@ -306,10 +361,13 @@ void KProcessRunner::emitDelayedError(const QString &errorMsg)
     qCWarning(KIO_GUI) << errorMsg;
     terminateStartupNotification();
     // Use delayed invocation so the caller has time to connect to the signal
-    QMetaObject::invokeMethod(this, [this, errorMsg]() {
-        emit error(errorMsg);
-        deleteLater();
-    }, Qt::QueuedConnection);
+    QMetaObject::invokeMethod(
+        this,
+        [this, errorMsg]() {
+            Q_EMIT error(errorMsg);
+            deleteLater();
+        },
+        Qt::QueuedConnection);
 }
 
 void ForkingProcessRunner::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
@@ -344,8 +402,8 @@ bool KIOGuiPrivate::checkStartupNotify(const KService *service, bool *silent_arg
             // virtual desktop, and will get user timestamp from the ASN ID.
             wmclass = '0';
             silent = true;
-#else   // That unfortunately doesn't work, when the launched non-compliant application
-            // launches another one that is compliant and there is any delay inbetween (bnc:#343359)
+#else // That unfortunately doesn't work, when the launched non-compliant application
+      // launches another one that is compliant and there is any delay inbetween (bnc:#343359)
             return false;
 #endif
         }
