@@ -1,43 +1,29 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2008 - 2009 Urs Wolfer <uwolfer @ kde.org>
- * Copyright (C) 2009 - 2012 Dawit Alemayehu <adawit @ kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE project.
+    SPDX-FileCopyrightText: 2008-2009 Urs Wolfer <uwolfer @ kde.org>
+    SPDX-FileCopyrightText: 2009-2012 Dawit Alemayehu <adawit @ kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KIO_ACCESSMANAGER_H
 #define KIO_ACCESSMANAGER_H
 
-#include <kio/global.h>
 #include "kiowidgets_export.h"
+#include <kio/global.h>
 #include <qwindowdefs.h> // WId
 
-#include <QtNetwork/QNetworkAccessManager>
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkCookieJar>
+#include <QNetworkAccessManager>
+#include <QNetworkCookieJar>
+#include <QNetworkRequest>
 
 class QWidget;
 
 namespace KIO
 {
-
 /**
+ * @class KIO::AccessManager accessmanager.h <KIO/AccessManager>
+ *
  * @short A KDE implementation of QNetworkAccessManager.
  *
  * Use this class instead of QNetworkAccessManager if you want to integrate
@@ -59,7 +45,7 @@ namespace KIO
  *   KIO::Integration::AccessManager *manager = qobject_cast<KIO::Integration::AccessManager*>(view->page()->accessManager());
  * @endcode
  *
- * Please note that this class is in the KIO namespace for backward compatablity.
+ * Please note that this class is in the KIO namespace for backward compatibility.
  * You should use KIO::Integration::AccessManager to access this class in your
  * code.
  *
@@ -83,7 +69,7 @@ public:
      */
     enum Attribute {
         MetaData = QNetworkRequest::User, /** < Used to send KIO MetaData back and forth. type: QVariant::Map. */
-        KioError /**< Used to send KIO error codes that cannot be mapped into QNetworkReply::NetworkError. type: QVariant::Int */
+        KioError, /**< Used to send KIO error codes that cannot be mapped into QNetworkReply::NetworkError. type: QVariant::Int */
     };
 
     /**
@@ -109,6 +95,7 @@ public:
      */
     bool isExternalContentAllowed() const;
 
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Sets the cookiejar's window id to @p id.
      *
@@ -123,10 +110,10 @@ public:
      *
      * @see KIO::Integration::CookieJar::setWindowId.
      * @since 4.4
-     * @deprecated Use setWindow
+     * @deprecated Since 5.0, use KIO::Integration::CookieJar::setWindowId
      */
-#ifndef KIOWIDGETS_NO_DEPRECATED
-    KIOWIDGETS_DEPRECATED void setCookieJarWindowId(WId id);
+    KIOWIDGETS_DEPRECATED_VERSION(5, 0, "Use KIO::Integration::CookieJar::setWindowId(...)")
+    void setCookieJarWindowId(WId id);
 #endif
 
     /**
@@ -141,6 +128,7 @@ public:
      */
     void setWindow(QWidget *widget);
 
+#if KIOWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Returns the cookiejar's window id.
      *
@@ -151,10 +139,10 @@ public:
      *
      * @see KIO::Integration::CookieJar::windowId.
      * @since 4.4
-     * @deprecated Use KIO::Integration::CookieJar::windowId
+     * @deprecated Since 5.0, use KIO::Integration::CookieJar::windowId
      */
-#ifndef KIOWIDGETS_NO_DEPRECATED
-    KIOWIDGETS_DEPRECATED WId cookieJarWindowid() const;
+    KIOWIDGETS_DEPRECATED_VERSION(5, 0, "Use KIO::Integration::CookieJar::windowId()")
+    WId cookieJarWindowid() const;
 #endif
 
     /**
@@ -228,7 +216,7 @@ protected:
      * @see QNetworkAccessManager::createRequest
      * @internal
      */
-    QNetworkReply *createRequest(Operation op, const QNetworkRequest &req, QIODevice *outgoingData = nullptr) Q_DECL_OVERRIDE;
+    QNetworkReply *createRequest(Operation op, const QNetworkRequest &req, QIODevice *outgoingData = nullptr) override;
 
 private:
     class AccessManagerPrivate;
@@ -249,6 +237,8 @@ typedef KIO::AccessManager AccessManager;
 KIOWIDGETS_EXPORT bool sslConfigFromMetaData(const KIO::MetaData &metadata, QSslConfiguration &sslconfig);
 
 /**
+ * @class KIO::CookieJar accessmanager.h <KIO/AccessManager>
+ *
  * @short A KDE implementation of QNetworkCookieJar.
  *
  * Use this class in place of QNetworkCookieJar if you want to integrate with
@@ -271,7 +261,7 @@ KIOWIDGETS_EXPORT bool sslConfigFromMetaData(const KIO::MetaData &metadata, QSsl
  * @endcode
  *
  * <b>IMPORTANT</b>This class is not a replacement for the standard KDE API.
- * It should ONLY be used to to provide KDE integration in applications that
+ * It should ONLY be used to provide KDE integration in applications that
  * cannot use the standard KDE API directly.
  *
  * @see QNetworkAccessManager::setCookieJar for details.
@@ -323,7 +313,7 @@ public:
      * @see QNetworkCookieJar::cookiesForUrl
      * @internal
      */
-    QList<QNetworkCookie> cookiesForUrl(const QUrl &url) const Q_DECL_OVERRIDE;
+    QList<QNetworkCookie> cookiesForUrl(const QUrl &url) const override;
 
     /**
      * Reimplemented for internal reasons, the API is not affected.
@@ -331,7 +321,7 @@ public:
      * @see QNetworkCookieJar::setCookiesFromUrl
      * @internal
      */
-    bool setCookiesFromUrl(const QList<QNetworkCookie> &cookieList, const QUrl &url) Q_DECL_OVERRIDE;
+    bool setCookiesFromUrl(const QList<QNetworkCookie> &cookieList, const QUrl &url) override;
 
     /**
      * Returns true if persistent caching of cookies is disabled.
